# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/exchange/v1beta1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from injective.oracle.v1beta1 import oracle_pb2 as injective_dot_oracle_dot_v1beta1_dot_oracle__pb2
from injective.exchange.v1beta1 import exchange_pb2 as injective_dot_exchange_dot_v1beta1_dot_exchange__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from cosmos.distribution.v1beta1 import distribution_pb2 as cosmos_dot_distribution_dot_v1beta1_dot_distribution__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#injective/exchange/v1beta1/tx.proto\x12\x1ainjective.exchange.v1beta1\x1a\x14gogoproto/gogo.proto\x1a%injective/oracle/v1beta1/oracle.proto\x1a)injective/exchange/v1beta1/exchange.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a.cosmos/distribution/v1beta1/distribution.proto\x1a\x19\x63osmos_proto/cosmos.proto\"n\n\nMsgDeposit\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x15\n\rsubaccount_id\x18\x02 \x01(\t\x12/\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x14\n\x12MsgDepositResponse\"o\n\x0bMsgWithdraw\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x15\n\rsubaccount_id\x18\x02 \x01(\t\x12/\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x15\n\x13MsgWithdrawResponse\"o\n\x17MsgCreateSpotLimitOrder\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12:\n\x05order\x18\x02 \x01(\x0b\x32%.injective.exchange.v1beta1.SpotOrderB\x04\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"?\n\x1fMsgCreateSpotLimitOrderResponse\x12\x12\n\norder_hash\x18\x01 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"v\n\x1dMsgBatchCreateSpotLimitOrders\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12;\n\x06orders\x18\x02 \x03(\x0b\x32%.injective.exchange.v1beta1.SpotOrderB\x04\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"G\n%MsgBatchCreateSpotLimitOrdersResponse\x12\x14\n\x0corder_hashes\x18\x01 \x03(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x8c\x02\n\x1aMsgInstantSpotMarketLaunch\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x0e\n\x06ticker\x18\x02 \x01(\t\x12\x12\n\nbase_denom\x18\x03 \x01(\t\x12\x13\n\x0bquote_denom\x18\x04 \x01(\t\x12K\n\x13min_price_tick_size\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12N\n\x16min_quantity_tick_size\x18\x06 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"$\n\"MsgInstantSpotMarketLaunchResponse\"\xb0\x05\n\x1fMsgInstantPerpetualMarketLaunch\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x0e\n\x06ticker\x18\x02 \x01(\t\x12\x13\n\x0bquote_denom\x18\x03 \x01(\t\x12\x13\n\x0boracle_base\x18\x04 \x01(\t\x12\x14\n\x0coracle_quote\x18\x05 \x01(\t\x12\x1b\n\x13oracle_scale_factor\x18\x06 \x01(\r\x12\x39\n\x0boracle_type\x18\x07 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleType\x12\x46\n\x0emaker_fee_rate\x18\x08 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x46\n\x0etaker_fee_rate\x18\t \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12L\n\x14initial_margin_ratio\x18\n \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12P\n\x18maintenance_margin_ratio\x18\x0b \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12K\n\x13min_price_tick_size\x18\x0c \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12N\n\x16min_quantity_tick_size\x18\r \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\")\n\'MsgInstantPerpetualMarketLaunchResponse\"\xe4\x04\n#MsgInstantBinaryOptionsMarketLaunch\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x0e\n\x06ticker\x18\x02 \x01(\t\x12\x15\n\roracle_symbol\x18\x03 \x01(\t\x12\x17\n\x0foracle_provider\x18\x04 \x01(\t\x12\x39\n\x0boracle_type\x18\x05 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleType\x12\x1b\n\x13oracle_scale_factor\x18\x06 \x01(\r\x12\x46\n\x0emaker_fee_rate\x18\x07 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x46\n\x0etaker_fee_rate\x18\x08 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x1c\n\x14\x65xpiration_timestamp\x18\t \x01(\x03\x12\x1c\n\x14settlement_timestamp\x18\n \x01(\x03\x12\r\n\x05\x61\x64min\x18\x0b \x01(\t\x12\x13\n\x0bquote_denom\x18\x0c \x01(\t\x12K\n\x13min_price_tick_size\x18\r \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12N\n\x16min_quantity_tick_size\x18\x0e \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"-\n+MsgInstantBinaryOptionsMarketLaunchResponse\"\xc4\x05\n#MsgInstantExpiryFuturesMarketLaunch\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x0e\n\x06ticker\x18\x02 \x01(\t\x12\x13\n\x0bquote_denom\x18\x03 \x01(\t\x12\x13\n\x0boracle_base\x18\x04 \x01(\t\x12\x14\n\x0coracle_quote\x18\x05 \x01(\t\x12\x39\n\x0boracle_type\x18\x06 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleType\x12\x1b\n\x13oracle_scale_factor\x18\x07 \x01(\r\x12\x0e\n\x06\x65xpiry\x18\x08 \x01(\x03\x12\x46\n\x0emaker_fee_rate\x18\t \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x46\n\x0etaker_fee_rate\x18\n \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12L\n\x14initial_margin_ratio\x18\x0b \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12P\n\x18maintenance_margin_ratio\x18\x0c \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12K\n\x13min_price_tick_size\x18\r \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12N\n\x16min_quantity_tick_size\x18\x0e \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"-\n+MsgInstantExpiryFuturesMarketLaunchResponse\"p\n\x18MsgCreateSpotMarketOrder\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12:\n\x05order\x18\x02 \x01(\x0b\x32%.injective.exchange.v1beta1.SpotOrderB\x04\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x8b\x01\n MsgCreateSpotMarketOrderResponse\x12\x12\n\norder_hash\x18\x01 \x01(\t\x12I\n\x07results\x18\x02 \x01(\x0b\x32\x32.injective.exchange.v1beta1.SpotMarketOrderResultsB\x04\xc8\xde\x1f\x01:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\xe0\x01\n\x16SpotMarketOrderResults\x12@\n\x08quantity\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12=\n\x05price\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12;\n\x03\x66\x65\x65\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"w\n\x1dMsgCreateDerivativeLimitOrder\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12@\n\x05order\x18\x02 \x01(\x0b\x32+.injective.exchange.v1beta1.DerivativeOrderB\x04\xc8\xde\x1f\x00:\x04\x88\xa0\x1f\x00\"E\n%MsgCreateDerivativeLimitOrderResponse\x12\x12\n\norder_hash\x18\x01 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"z\n MsgCreateBinaryOptionsLimitOrder\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12@\n\x05order\x18\x02 \x01(\x0b\x32+.injective.exchange.v1beta1.DerivativeOrderB\x04\xc8\xde\x1f\x00:\x04\x88\xa0\x1f\x00\"H\n(MsgCreateBinaryOptionsLimitOrderResponse\x12\x12\n\norder_hash\x18\x01 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"~\n#MsgBatchCreateDerivativeLimitOrders\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x41\n\x06orders\x18\x02 \x03(\x0b\x32+.injective.exchange.v1beta1.DerivativeOrderB\x04\xc8\xde\x1f\x00:\x04\x88\xa0\x1f\x00\"M\n+MsgBatchCreateDerivativeLimitOrdersResponse\x12\x14\n\x0corder_hashes\x18\x01 \x03(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"h\n\x12MsgCancelSpotOrder\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12\x15\n\rsubaccount_id\x18\x03 \x01(\t\x12\x12\n\norder_hash\x18\x04 \x01(\t:\x04\x88\xa0\x1f\x00\"\x1c\n\x1aMsgCancelSpotOrderResponse\"k\n\x18MsgBatchCancelSpotOrders\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x39\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32%.injective.exchange.v1beta1.OrderDataB\x04\xc8\xde\x1f\x00:\x04\x88\xa0\x1f\x00\"=\n MsgBatchCancelSpotOrdersResponse\x12\x0f\n\x07success\x18\x01 \x03(\x08:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"t\n!MsgBatchCancelBinaryOptionsOrders\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x39\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32%.injective.exchange.v1beta1.OrderDataB\x04\xc8\xde\x1f\x00:\x04\x88\xa0\x1f\x00\"F\n)MsgBatchCancelBinaryOptionsOrdersResponse\x12\x0f\n\x07success\x18\x01 \x03(\x08:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\xbc\x05\n\x14MsgBatchUpdateOrders\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x15\n\rsubaccount_id\x18\x02 \x01(\t\x12%\n\x1dspot_market_ids_to_cancel_all\x18\x03 \x03(\t\x12+\n#derivative_market_ids_to_cancel_all\x18\x04 \x03(\t\x12J\n\x15spot_orders_to_cancel\x18\x05 \x03(\x0b\x32%.injective.exchange.v1beta1.OrderDataB\x04\xc8\xde\x1f\x01\x12P\n\x1b\x64\x65rivative_orders_to_cancel\x18\x06 \x03(\x0b\x32%.injective.exchange.v1beta1.OrderDataB\x04\xc8\xde\x1f\x01\x12J\n\x15spot_orders_to_create\x18\x07 \x03(\x0b\x32%.injective.exchange.v1beta1.SpotOrderB\x04\xc8\xde\x1f\x01\x12V\n\x1b\x64\x65rivative_orders_to_create\x18\x08 \x03(\x0b\x32+.injective.exchange.v1beta1.DerivativeOrderB\x04\xc8\xde\x1f\x01\x12T\n\x1f\x62inary_options_orders_to_cancel\x18\t \x03(\x0b\x32%.injective.exchange.v1beta1.OrderDataB\x04\xc8\xde\x1f\x01\x12/\n\'binary_options_market_ids_to_cancel_all\x18\n \x03(\t\x12Z\n\x1f\x62inary_options_orders_to_create\x18\x0b \x03(\x0b\x32+.injective.exchange.v1beta1.DerivativeOrderB\x04\xc8\xde\x1f\x01:\x04\x88\xa0\x1f\x00\"\xf0\x01\n\x1cMsgBatchUpdateOrdersResponse\x12\x1b\n\x13spot_cancel_success\x18\x01 \x03(\x08\x12!\n\x19\x64\x65rivative_cancel_success\x18\x02 \x03(\x08\x12\x19\n\x11spot_order_hashes\x18\x03 \x03(\t\x12\x1f\n\x17\x64\x65rivative_order_hashes\x18\x04 \x03(\t\x12%\n\x1d\x62inary_options_cancel_success\x18\x05 \x03(\x08\x12#\n\x1b\x62inary_options_order_hashes\x18\x06 \x03(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"x\n\x1eMsgCreateDerivativeMarketOrder\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12@\n\x05order\x18\x02 \x01(\x0b\x32+.injective.exchange.v1beta1.DerivativeOrderB\x04\xc8\xde\x1f\x00:\x04\x88\xa0\x1f\x00\"\x97\x01\n&MsgCreateDerivativeMarketOrderResponse\x12\x12\n\norder_hash\x18\x01 \x01(\t\x12O\n\x07results\x18\x02 \x01(\x0b\x32\x38.injective.exchange.v1beta1.DerivativeMarketOrderResultsB\x04\xc8\xde\x1f\x01:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\xef\x02\n\x1c\x44\x65rivativeMarketOrderResults\x12@\n\x08quantity\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12=\n\x05price\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12;\n\x03\x66\x65\x65\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12G\n\x0eposition_delta\x18\x04 \x01(\x0b\x32).injective.exchange.v1beta1.PositionDeltaB\x04\xc8\xde\x1f\x00\x12>\n\x06payout\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"{\n!MsgCreateBinaryOptionsMarketOrder\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12@\n\x05order\x18\x02 \x01(\x0b\x32+.injective.exchange.v1beta1.DerivativeOrderB\x04\xc8\xde\x1f\x00:\x04\x88\xa0\x1f\x00\"\x9a\x01\n)MsgCreateBinaryOptionsMarketOrderResponse\x12\x12\n\norder_hash\x18\x01 \x01(\t\x12O\n\x07results\x18\x02 \x01(\x0b\x32\x38.injective.exchange.v1beta1.DerivativeMarketOrderResultsB\x04\xc8\xde\x1f\x01:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x82\x01\n\x18MsgCancelDerivativeOrder\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12\x15\n\rsubaccount_id\x18\x03 \x01(\t\x12\x12\n\norder_hash\x18\x04 \x01(\t\x12\x12\n\norder_mask\x18\x05 \x01(\x05:\x04\x88\xa0\x1f\x00\"\"\n MsgCancelDerivativeOrderResponse\"\x85\x01\n\x1bMsgCancelBinaryOptionsOrder\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12\x15\n\rsubaccount_id\x18\x03 \x01(\t\x12\x12\n\norder_hash\x18\x04 \x01(\t\x12\x12\n\norder_mask\x18\x05 \x01(\x05:\x04\x88\xa0\x1f\x00\"%\n#MsgCancelBinaryOptionsOrderResponse\"]\n\tOrderData\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x15\n\rsubaccount_id\x18\x02 \x01(\t\x12\x12\n\norder_hash\x18\x03 \x01(\t\x12\x12\n\norder_mask\x18\x04 \x01(\x05\"q\n\x1eMsgBatchCancelDerivativeOrders\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x39\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32%.injective.exchange.v1beta1.OrderDataB\x04\xc8\xde\x1f\x00:\x04\x88\xa0\x1f\x00\"C\n&MsgBatchCancelDerivativeOrdersResponse\x12\x0f\n\x07success\x18\x01 \x03(\x08:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x99\x01\n\x15MsgSubaccountTransfer\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x1c\n\x14source_subaccount_id\x18\x02 \x01(\t\x12!\n\x19\x64\x65stination_subaccount_id\x18\x03 \x01(\t\x12/\n\x06\x61mount\x18\x04 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\"\x1f\n\x1dMsgSubaccountTransferResponse\"\x97\x01\n\x13MsgExternalTransfer\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x1c\n\x14source_subaccount_id\x18\x02 \x01(\t\x12!\n\x19\x64\x65stination_subaccount_id\x18\x03 \x01(\t\x12/\n\x06\x61mount\x18\x04 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\"\x1d\n\x1bMsgExternalTransferResponse\"\x92\x01\n\x14MsgLiquidatePosition\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x15\n\rsubaccount_id\x18\x02 \x01(\t\x12\x11\n\tmarket_id\x18\x03 \x01(\t\x12@\n\x05order\x18\x04 \x01(\x0b\x32+.injective.exchange.v1beta1.DerivativeOrderB\x04\xc8\xde\x1f\x01\"\x1e\n\x1cMsgLiquidatePositionResponse\"\xbf\x01\n\x19MsgIncreasePositionMargin\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x1c\n\x14source_subaccount_id\x18\x02 \x01(\t\x12!\n\x19\x64\x65stination_subaccount_id\x18\x03 \x01(\t\x12\x11\n\tmarket_id\x18\x04 \x01(\t\x12>\n\x06\x61mount\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"#\n!MsgIncreasePositionMarginResponse\"o\n\x1cMsgPrivilegedExecuteContract\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\r\n\x05\x66unds\x18\x02 \x01(\t\x12\x18\n\x10\x63ontract_address\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x91\x01\n$MsgPrivilegedExecuteContractResponse\x12_\n\nfunds_diff\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x97\x04\n\x1dSpotMarketParamUpdateProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x11\n\tmarket_id\x18\x03 \x01(\t\x12\x46\n\x0emaker_fee_rate\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12\x46\n\x0etaker_fee_rate\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12N\n\x16relayer_fee_share_rate\x18\x06 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12K\n\x13min_price_tick_size\x18\x07 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12N\n\x16min_quantity_tick_size\x18\x08 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12\x38\n\x06status\x18\t \x01(\x0e\x32(.injective.exchange.v1beta1.MarketStatus:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x86\x01\n\x16\x45xchangeEnableProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12>\n\x0c\x65xchangeType\x18\x03 \x01(\x0e\x32(.injective.exchange.v1beta1.ExchangeType:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x91\x08\n!BatchExchangeModificationProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x65\n\"spot_market_param_update_proposals\x18\x03 \x03(\x0b\x32\x39.injective.exchange.v1beta1.SpotMarketParamUpdateProposal\x12q\n(derivative_market_param_update_proposals\x18\x04 \x03(\x0b\x32?.injective.exchange.v1beta1.DerivativeMarketParamUpdateProposal\x12Z\n\x1cspot_market_launch_proposals\x18\x05 \x03(\x0b\x32\x34.injective.exchange.v1beta1.SpotMarketLaunchProposal\x12\x64\n!perpetual_market_launch_proposals\x18\x06 \x03(\x0b\x32\x39.injective.exchange.v1beta1.PerpetualMarketLaunchProposal\x12m\n&expiry_futures_market_launch_proposals\x18\x07 \x03(\x0b\x32=.injective.exchange.v1beta1.ExpiryFuturesMarketLaunchProposal\x12p\n\'trading_reward_campaign_update_proposal\x18\x08 \x01(\x0b\x32?.injective.exchange.v1beta1.TradingRewardCampaignUpdateProposal\x12m\n&binary_options_market_launch_proposals\x18\t \x03(\x0b\x32=.injective.exchange.v1beta1.BinaryOptionsMarketLaunchProposal\x12q\n%binary_options_param_update_proposals\x18\n \x03(\x0b\x32\x42.injective.exchange.v1beta1.BinaryOptionsMarketParamUpdateProposal\x12_\n\x1e\x64\x65nom_decimals_update_proposal\x18\x0b \x01(\x0b\x32\x37.injective.exchange.v1beta1.UpdateDenomDecimalsProposal:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\xae\x03\n\x18SpotMarketLaunchProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06ticker\x18\x03 \x01(\t\x12\x12\n\nbase_denom\x18\x04 \x01(\t\x12\x13\n\x0bquote_denom\x18\x05 \x01(\t\x12K\n\x13min_price_tick_size\x18\x06 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12N\n\x16min_quantity_tick_size\x18\x07 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x46\n\x0emaker_fee_rate\x18\x08 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12\x46\n\x0etaker_fee_rate\x18\t \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\xc2\x05\n\x1dPerpetualMarketLaunchProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06ticker\x18\x03 \x01(\t\x12\x13\n\x0bquote_denom\x18\x04 \x01(\t\x12\x13\n\x0boracle_base\x18\x05 \x01(\t\x12\x14\n\x0coracle_quote\x18\x06 \x01(\t\x12\x1b\n\x13oracle_scale_factor\x18\x07 \x01(\r\x12\x39\n\x0boracle_type\x18\x08 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleType\x12L\n\x14initial_margin_ratio\x18\t \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12P\n\x18maintenance_margin_ratio\x18\n \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x46\n\x0emaker_fee_rate\x18\x0b \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x46\n\x0etaker_fee_rate\x18\x0c \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12K\n\x13min_price_tick_size\x18\r \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12N\n\x16min_quantity_tick_size\x18\x0e \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\xf6\x04\n!BinaryOptionsMarketLaunchProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06ticker\x18\x03 \x01(\t\x12\x15\n\roracle_symbol\x18\x04 \x01(\t\x12\x17\n\x0foracle_provider\x18\x05 \x01(\t\x12\x39\n\x0boracle_type\x18\x06 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleType\x12\x1b\n\x13oracle_scale_factor\x18\x07 \x01(\r\x12\x1c\n\x14\x65xpiration_timestamp\x18\x08 \x01(\x03\x12\x1c\n\x14settlement_timestamp\x18\t \x01(\x03\x12\r\n\x05\x61\x64min\x18\n \x01(\t\x12\x13\n\x0bquote_denom\x18\x0b \x01(\t\x12\x46\n\x0emaker_fee_rate\x18\x0c \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x46\n\x0etaker_fee_rate\x18\r \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12K\n\x13min_price_tick_size\x18\x0e \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12N\n\x16min_quantity_tick_size\x18\x0f \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\xd6\x05\n!ExpiryFuturesMarketLaunchProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06ticker\x18\x03 \x01(\t\x12\x13\n\x0bquote_denom\x18\x04 \x01(\t\x12\x13\n\x0boracle_base\x18\x05 \x01(\t\x12\x14\n\x0coracle_quote\x18\x06 \x01(\t\x12\x1b\n\x13oracle_scale_factor\x18\x07 \x01(\r\x12\x39\n\x0boracle_type\x18\x08 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleType\x12\x0e\n\x06\x65xpiry\x18\t \x01(\x03\x12L\n\x14initial_margin_ratio\x18\n \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12P\n\x18maintenance_margin_ratio\x18\x0b \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x46\n\x0emaker_fee_rate\x18\x0c \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x46\n\x0etaker_fee_rate\x18\r \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12K\n\x13min_price_tick_size\x18\x0e \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12N\n\x16min_quantity_tick_size\x18\x0f \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x98\x07\n#DerivativeMarketParamUpdateProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x11\n\tmarket_id\x18\x03 \x01(\t\x12L\n\x14initial_margin_ratio\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12P\n\x18maintenance_margin_ratio\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12\x46\n\x0emaker_fee_rate\x18\x06 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12\x46\n\x0etaker_fee_rate\x18\x07 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12N\n\x16relayer_fee_share_rate\x18\x08 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12K\n\x13min_price_tick_size\x18\t \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12N\n\x16min_quantity_tick_size\x18\n \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12J\n\x12HourlyInterestRate\x18\x0b \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12L\n\x14HourlyFundingRateCap\x18\x0c \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12\x38\n\x06status\x18\r \x01(\x0e\x32(.injective.exchange.v1beta1.MarketStatus\x12?\n\roracle_params\x18\x0e \x01(\x0b\x32(.injective.exchange.v1beta1.OracleParams:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\xab\x01\n\x1eMarketForcedSettlementProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x11\n\tmarket_id\x18\x03 \x01(\t\x12H\n\x10settlement_price\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x8e\x01\n\x1bUpdateDenomDecimalsProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x41\n\x0e\x64\x65nom_decimals\x18\x03 \x03(\x0b\x32).injective.exchange.v1beta1.DenomDecimals:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\xfe\x05\n&BinaryOptionsMarketParamUpdateProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x11\n\tmarket_id\x18\x03 \x01(\t\x12\x46\n\x0emaker_fee_rate\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12\x46\n\x0etaker_fee_rate\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12N\n\x16relayer_fee_share_rate\x18\x06 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12K\n\x13min_price_tick_size\x18\x07 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12N\n\x16min_quantity_tick_size\x18\x08 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12\x1c\n\x14\x65xpiration_timestamp\x18\t \x01(\x03\x12\x1c\n\x14settlement_timestamp\x18\n \x01(\x03\x12H\n\x10settlement_price\x18\x0b \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12\r\n\x05\x61\x64min\x18\x0c \x01(\t\x12\x38\n\x06status\x18\r \x01(\x0e\x32(.injective.exchange.v1beta1.MarketStatus\x12G\n\roracle_params\x18\x0e \x01(\x0b\x32\x30.injective.exchange.v1beta1.ProviderOracleParams:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x90\x01\n\x14ProviderOracleParams\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x10\n\x08provider\x18\x02 \x01(\t\x12\x1b\n\x13oracle_scale_factor\x18\x03 \x01(\r\x12\x39\n\x0boracle_type\x18\x04 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleType\"\x91\x01\n\x0cOracleParams\x12\x13\n\x0boracle_base\x18\x01 \x01(\t\x12\x14\n\x0coracle_quote\x18\x02 \x01(\t\x12\x1b\n\x13oracle_scale_factor\x18\x03 \x01(\r\x12\x39\n\x0boracle_type\x18\x04 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleType\"\xf0\x01\n#TradingRewardCampaignLaunchProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12L\n\rcampaign_info\x18\x03 \x01(\x0b\x32\x35.injective.exchange.v1beta1.TradingRewardCampaignInfo\x12M\n\x15\x63\x61mpaign_reward_pools\x18\x04 \x03(\x0b\x32..injective.exchange.v1beta1.CampaignRewardPool:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\xd1\x02\n#TradingRewardCampaignUpdateProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12L\n\rcampaign_info\x18\x03 \x01(\x0b\x32\x35.injective.exchange.v1beta1.TradingRewardCampaignInfo\x12W\n\x1f\x63\x61mpaign_reward_pools_additions\x18\x04 \x03(\x0b\x32..injective.exchange.v1beta1.CampaignRewardPool\x12U\n\x1d\x63\x61mpaign_reward_pools_updates\x18\x05 \x03(\x0b\x32..injective.exchange.v1beta1.CampaignRewardPool:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"p\n\x11RewardPointUpdate\x12\x17\n\x0f\x61\x63\x63ount_address\x18\x01 \x01(\t\x12\x42\n\nnew_points\x18\x0c \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"\xc5\x01\n(TradingRewardPendingPointsUpdateProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x1e\n\x16pending_pool_timestamp\x18\x03 \x01(\x03\x12K\n\x14reward_point_updates\x18\x04 \x03(\x0b\x32-.injective.exchange.v1beta1.RewardPointUpdate:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x86\x01\n\x13\x46\x65\x65\x44iscountProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x41\n\x08schedule\x18\x03 \x01(\x0b\x32/.injective.exchange.v1beta1.FeeDiscountSchedule:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x9b\x01\n\x1f\x42\x61tchCommunityPoolSpendProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12J\n\tproposals\x18\x03 \x03(\x0b\x32\x37.cosmos.distribution.v1beta1.CommunityPoolSpendProposal:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\"\n\x10MsgRewardsOptOut\x12\x0e\n\x06sender\x18\x01 \x01(\t\"\x1a\n\x18MsgRewardsOptOutResponse\"W\n\x15MsgReclaimLockedFunds\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x1b\n\x13lockedAccountPubKey\x18\x02 \x01(\x0c\x12\x11\n\tsignature\x18\x03 \x01(\x0c\"\x1f\n\x1dMsgReclaimLockedFundsResponse\"r\n\x0bMsgSignData\x12K\n\x06Signer\x18\x01 \x01(\x0c\x42;\xea\xde\x1f\x06signer\xfa\xde\x1f-github.com/cosmos/cosmos-sdk/types.AccAddress\x12\x16\n\x04\x44\x61ta\x18\x02 \x01(\x0c\x42\x08\xea\xde\x1f\x04\x64\x61ta\"g\n\nMsgSignDoc\x12\x1b\n\tsign_type\x18\x01 \x01(\tB\x08\xea\xde\x1f\x04type\x12<\n\x05value\x18\x02 \x01(\x0b\x32\'.injective.exchange.v1beta1.MsgSignDataB\x04\xc8\xde\x1f\x00\"\x86\x02\n!MsgAdminUpdateBinaryOptionsMarket\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12H\n\x10settlement_price\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12\x1c\n\x14\x65xpiration_timestamp\x18\x04 \x01(\x03\x12\x1c\n\x14settlement_timestamp\x18\x05 \x01(\x03\x12\x38\n\x06status\x18\x06 \x01(\x0e\x32(.injective.exchange.v1beta1.MarketStatus\"+\n)MsgAdminUpdateBinaryOptionsMarketResponse\"\xaf\x01\n.AtomicMarketOrderFeeMultiplierScheduleProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12O\n\x16market_fee_multipliers\x18\x03 \x03(\x0b\x32/.injective.exchange.v1beta1.MarketFeeMultiplier:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00*x\n\x0c\x45xchangeType\x12\x32\n\x14\x45XCHANGE_UNSPECIFIED\x10\x00\x1a\x18\x8a\x9d \x14\x45XCHANGE_UNSPECIFIED\x12\x12\n\x04SPOT\x10\x01\x1a\x08\x8a\x9d \x04SPOT\x12 \n\x0b\x44\x45RIVATIVES\x10\x02\x1a\x0f\x8a\x9d \x0b\x44\x45RIVATIVES2\x9e!\n\x03Msg\x12\x61\n\x07\x44\x65posit\x12&.injective.exchange.v1beta1.MsgDeposit\x1a..injective.exchange.v1beta1.MsgDepositResponse\x12\x64\n\x08Withdraw\x12\'.injective.exchange.v1beta1.MsgWithdraw\x1a/.injective.exchange.v1beta1.MsgWithdrawResponse\x12\x91\x01\n\x17InstantSpotMarketLaunch\x12\x36.injective.exchange.v1beta1.MsgInstantSpotMarketLaunch\x1a>.injective.exchange.v1beta1.MsgInstantSpotMarketLaunchResponse\x12\xa0\x01\n\x1cInstantPerpetualMarketLaunch\x12;.injective.exchange.v1beta1.MsgInstantPerpetualMarketLaunch\x1a\x43.injective.exchange.v1beta1.MsgInstantPerpetualMarketLaunchResponse\x12\xac\x01\n InstantExpiryFuturesMarketLaunch\x12?.injective.exchange.v1beta1.MsgInstantExpiryFuturesMarketLaunch\x1aG.injective.exchange.v1beta1.MsgInstantExpiryFuturesMarketLaunchResponse\x12\x88\x01\n\x14\x43reateSpotLimitOrder\x12\x33.injective.exchange.v1beta1.MsgCreateSpotLimitOrder\x1a;.injective.exchange.v1beta1.MsgCreateSpotLimitOrderResponse\x12\x9a\x01\n\x1a\x42\x61tchCreateSpotLimitOrders\x12\x39.injective.exchange.v1beta1.MsgBatchCreateSpotLimitOrders\x1a\x41.injective.exchange.v1beta1.MsgBatchCreateSpotLimitOrdersResponse\x12\x8b\x01\n\x15\x43reateSpotMarketOrder\x12\x34.injective.exchange.v1beta1.MsgCreateSpotMarketOrder\x1a<.injective.exchange.v1beta1.MsgCreateSpotMarketOrderResponse\x12y\n\x0f\x43\x61ncelSpotOrder\x12..injective.exchange.v1beta1.MsgCancelSpotOrder\x1a\x36.injective.exchange.v1beta1.MsgCancelSpotOrderResponse\x12\x8b\x01\n\x15\x42\x61tchCancelSpotOrders\x12\x34.injective.exchange.v1beta1.MsgBatchCancelSpotOrders\x1a<.injective.exchange.v1beta1.MsgBatchCancelSpotOrdersResponse\x12\x7f\n\x11\x42\x61tchUpdateOrders\x12\x30.injective.exchange.v1beta1.MsgBatchUpdateOrders\x1a\x38.injective.exchange.v1beta1.MsgBatchUpdateOrdersResponse\x12\x97\x01\n\x19PrivilegedExecuteContract\x12\x38.injective.exchange.v1beta1.MsgPrivilegedExecuteContract\x1a@.injective.exchange.v1beta1.MsgPrivilegedExecuteContractResponse\x12\x9a\x01\n\x1a\x43reateDerivativeLimitOrder\x12\x39.injective.exchange.v1beta1.MsgCreateDerivativeLimitOrder\x1a\x41.injective.exchange.v1beta1.MsgCreateDerivativeLimitOrderResponse\x12\xac\x01\n BatchCreateDerivativeLimitOrders\x12?.injective.exchange.v1beta1.MsgBatchCreateDerivativeLimitOrders\x1aG.injective.exchange.v1beta1.MsgBatchCreateDerivativeLimitOrdersResponse\x12\x9d\x01\n\x1b\x43reateDerivativeMarketOrder\x12:.injective.exchange.v1beta1.MsgCreateDerivativeMarketOrder\x1a\x42.injective.exchange.v1beta1.MsgCreateDerivativeMarketOrderResponse\x12\x8b\x01\n\x15\x43\x61ncelDerivativeOrder\x12\x34.injective.exchange.v1beta1.MsgCancelDerivativeOrder\x1a<.injective.exchange.v1beta1.MsgCancelDerivativeOrderResponse\x12\x9d\x01\n\x1b\x42\x61tchCancelDerivativeOrders\x12:.injective.exchange.v1beta1.MsgBatchCancelDerivativeOrders\x1a\x42.injective.exchange.v1beta1.MsgBatchCancelDerivativeOrdersResponse\x12\xac\x01\n InstantBinaryOptionsMarketLaunch\x12?.injective.exchange.v1beta1.MsgInstantBinaryOptionsMarketLaunch\x1aG.injective.exchange.v1beta1.MsgInstantBinaryOptionsMarketLaunchResponse\x12\xa3\x01\n\x1d\x43reateBinaryOptionsLimitOrder\x12<.injective.exchange.v1beta1.MsgCreateBinaryOptionsLimitOrder\x1a\x44.injective.exchange.v1beta1.MsgCreateBinaryOptionsLimitOrderResponse\x12\xa6\x01\n\x1e\x43reateBinaryOptionsMarketOrder\x12=.injective.exchange.v1beta1.MsgCreateBinaryOptionsMarketOrder\x1a\x45.injective.exchange.v1beta1.MsgCreateBinaryOptionsMarketOrderResponse\x12\x94\x01\n\x18\x43\x61ncelBinaryOptionsOrder\x12\x37.injective.exchange.v1beta1.MsgCancelBinaryOptionsOrder\x1a?.injective.exchange.v1beta1.MsgCancelBinaryOptionsOrderResponse\x12\xa6\x01\n\x1e\x42\x61tchCancelBinaryOptionsOrders\x12=.injective.exchange.v1beta1.MsgBatchCancelBinaryOptionsOrders\x1a\x45.injective.exchange.v1beta1.MsgBatchCancelBinaryOptionsOrdersResponse\x12\x82\x01\n\x12SubaccountTransfer\x12\x31.injective.exchange.v1beta1.MsgSubaccountTransfer\x1a\x39.injective.exchange.v1beta1.MsgSubaccountTransferResponse\x12|\n\x10\x45xternalTransfer\x12/.injective.exchange.v1beta1.MsgExternalTransfer\x1a\x37.injective.exchange.v1beta1.MsgExternalTransferResponse\x12\x7f\n\x11LiquidatePosition\x12\x30.injective.exchange.v1beta1.MsgLiquidatePosition\x1a\x38.injective.exchange.v1beta1.MsgLiquidatePositionResponse\x12\x8e\x01\n\x16IncreasePositionMargin\x12\x35.injective.exchange.v1beta1.MsgIncreasePositionMargin\x1a=.injective.exchange.v1beta1.MsgIncreasePositionMarginResponse\x12s\n\rRewardsOptOut\x12,.injective.exchange.v1beta1.MsgRewardsOptOut\x1a\x34.injective.exchange.v1beta1.MsgRewardsOptOutResponse\x12\xa6\x01\n\x1e\x41\x64minUpdateBinaryOptionsMarket\x12=.injective.exchange.v1beta1.MsgAdminUpdateBinaryOptionsMarket\x1a\x45.injective.exchange.v1beta1.MsgAdminUpdateBinaryOptionsMarketResponse\x12\x82\x01\n\x12ReclaimLockedFunds\x12\x31.injective.exchange.v1beta1.MsgReclaimLockedFunds\x1a\x39.injective.exchange.v1beta1.MsgReclaimLockedFundsResponseBPZNgithub.com/InjectiveLabs/injective-core/injective-chain/modules/exchange/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.exchange.v1beta1.tx_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZNgithub.com/InjectiveLabs/injective-core/injective-chain/modules/exchange/types'
  _EXCHANGETYPE.values_by_name["EXCHANGE_UNSPECIFIED"]._options = None
  _EXCHANGETYPE.values_by_name["EXCHANGE_UNSPECIFIED"]._serialized_options = b'\212\235 \024EXCHANGE_UNSPECIFIED'
  _EXCHANGETYPE.values_by_name["SPOT"]._options = None
  _EXCHANGETYPE.values_by_name["SPOT"]._serialized_options = b'\212\235 \004SPOT'
  _EXCHANGETYPE.values_by_name["DERIVATIVES"]._options = None
  _EXCHANGETYPE.values_by_name["DERIVATIVES"]._serialized_options = b'\212\235 \013DERIVATIVES'
  _MSGDEPOSIT.fields_by_name['amount']._options = None
  _MSGDEPOSIT.fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _MSGDEPOSIT._options = None
  _MSGDEPOSIT._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGWITHDRAW.fields_by_name['amount']._options = None
  _MSGWITHDRAW.fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _MSGWITHDRAW._options = None
  _MSGWITHDRAW._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGCREATESPOTLIMITORDER.fields_by_name['order']._options = None
  _MSGCREATESPOTLIMITORDER.fields_by_name['order']._serialized_options = b'\310\336\037\000'
  _MSGCREATESPOTLIMITORDER._options = None
  _MSGCREATESPOTLIMITORDER._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGCREATESPOTLIMITORDERRESPONSE._options = None
  _MSGCREATESPOTLIMITORDERRESPONSE._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGBATCHCREATESPOTLIMITORDERS.fields_by_name['orders']._options = None
  _MSGBATCHCREATESPOTLIMITORDERS.fields_by_name['orders']._serialized_options = b'\310\336\037\000'
  _MSGBATCHCREATESPOTLIMITORDERS._options = None
  _MSGBATCHCREATESPOTLIMITORDERS._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGBATCHCREATESPOTLIMITORDERSRESPONSE._options = None
  _MSGBATCHCREATESPOTLIMITORDERSRESPONSE._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGINSTANTSPOTMARKETLAUNCH.fields_by_name['min_price_tick_size']._options = None
  _MSGINSTANTSPOTMARKETLAUNCH.fields_by_name['min_price_tick_size']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _MSGINSTANTSPOTMARKETLAUNCH.fields_by_name['min_quantity_tick_size']._options = None
  _MSGINSTANTSPOTMARKETLAUNCH.fields_by_name['min_quantity_tick_size']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _MSGINSTANTSPOTMARKETLAUNCH._options = None
  _MSGINSTANTSPOTMARKETLAUNCH._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGINSTANTPERPETUALMARKETLAUNCH.fields_by_name['maker_fee_rate']._options = None
  _MSGINSTANTPERPETUALMARKETLAUNCH.fields_by_name['maker_fee_rate']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _MSGINSTANTPERPETUALMARKETLAUNCH.fields_by_name['taker_fee_rate']._options = None
  _MSGINSTANTPERPETUALMARKETLAUNCH.fields_by_name['taker_fee_rate']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _MSGINSTANTPERPETUALMARKETLAUNCH.fields_by_name['initial_margin_ratio']._options = None
  _MSGINSTANTPERPETUALMARKETLAUNCH.fields_by_name['initial_margin_ratio']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _MSGINSTANTPERPETUALMARKETLAUNCH.fields_by_name['maintenance_margin_ratio']._options = None
  _MSGINSTANTPERPETUALMARKETLAUNCH.fields_by_name['maintenance_margin_ratio']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _MSGINSTANTPERPETUALMARKETLAUNCH.fields_by_name['min_price_tick_size']._options = None
  _MSGINSTANTPERPETUALMARKETLAUNCH.fields_by_name['min_price_tick_size']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _MSGINSTANTPERPETUALMARKETLAUNCH.fields_by_name['min_quantity_tick_size']._options = None
  _MSGINSTANTPERPETUALMARKETLAUNCH.fields_by_name['min_quantity_tick_size']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _MSGINSTANTPERPETUALMARKETLAUNCH._options = None
  _MSGINSTANTPERPETUALMARKETLAUNCH._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGINSTANTBINARYOPTIONSMARKETLAUNCH.fields_by_name['maker_fee_rate']._options = None
  _MSGINSTANTBINARYOPTIONSMARKETLAUNCH.fields_by_name['maker_fee_rate']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _MSGINSTANTBINARYOPTIONSMARKETLAUNCH.fields_by_name['taker_fee_rate']._options = None
  _MSGINSTANTBINARYOPTIONSMARKETLAUNCH.fields_by_name['taker_fee_rate']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _MSGINSTANTBINARYOPTIONSMARKETLAUNCH.fields_by_name['min_price_tick_size']._options = None
  _MSGINSTANTBINARYOPTIONSMARKETLAUNCH.fields_by_name['min_price_tick_size']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _MSGINSTANTBINARYOPTIONSMARKETLAUNCH.fields_by_name['min_quantity_tick_size']._options = None
  _MSGINSTANTBINARYOPTIONSMARKETLAUNCH.fields_by_name['min_quantity_tick_size']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _MSGINSTANTBINARYOPTIONSMARKETLAUNCH._options = None
  _MSGINSTANTBINARYOPTIONSMARKETLAUNCH._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGINSTANTEXPIRYFUTURESMARKETLAUNCH.fields_by_name['maker_fee_rate']._options = None
  _MSGINSTANTEXPIRYFUTURESMARKETLAUNCH.fields_by_name['maker_fee_rate']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _MSGINSTANTEXPIRYFUTURESMARKETLAUNCH.fields_by_name['taker_fee_rate']._options = None
  _MSGINSTANTEXPIRYFUTURESMARKETLAUNCH.fields_by_name['taker_fee_rate']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _MSGINSTANTEXPIRYFUTURESMARKETLAUNCH.fields_by_name['initial_margin_ratio']._options = None
  _MSGINSTANTEXPIRYFUTURESMARKETLAUNCH.fields_by_name['initial_margin_ratio']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _MSGINSTANTEXPIRYFUTURESMARKETLAUNCH.fields_by_name['maintenance_margin_ratio']._options = None
  _MSGINSTANTEXPIRYFUTURESMARKETLAUNCH.fields_by_name['maintenance_margin_ratio']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _MSGINSTANTEXPIRYFUTURESMARKETLAUNCH.fields_by_name['min_price_tick_size']._options = None
  _MSGINSTANTEXPIRYFUTURESMARKETLAUNCH.fields_by_name['min_price_tick_size']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _MSGINSTANTEXPIRYFUTURESMARKETLAUNCH.fields_by_name['min_quantity_tick_size']._options = None
  _MSGINSTANTEXPIRYFUTURESMARKETLAUNCH.fields_by_name['min_quantity_tick_size']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _MSGINSTANTEXPIRYFUTURESMARKETLAUNCH._options = None
  _MSGINSTANTEXPIRYFUTURESMARKETLAUNCH._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGCREATESPOTMARKETORDER.fields_by_name['order']._options = None
  _MSGCREATESPOTMARKETORDER.fields_by_name['order']._serialized_options = b'\310\336\037\000'
  _MSGCREATESPOTMARKETORDER._options = None
  _MSGCREATESPOTMARKETORDER._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGCREATESPOTMARKETORDERRESPONSE.fields_by_name['results']._options = None
  _MSGCREATESPOTMARKETORDERRESPONSE.fields_by_name['results']._serialized_options = b'\310\336\037\001'
  _MSGCREATESPOTMARKETORDERRESPONSE._options = None
  _MSGCREATESPOTMARKETORDERRESPONSE._serialized_options = b'\350\240\037\000\210\240\037\000'
  _SPOTMARKETORDERRESULTS.fields_by_name['quantity']._options = None
  _SPOTMARKETORDERRESULTS.fields_by_name['quantity']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _SPOTMARKETORDERRESULTS.fields_by_name['price']._options = None
  _SPOTMARKETORDERRESULTS.fields_by_name['price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _SPOTMARKETORDERRESULTS.fields_by_name['fee']._options = None
  _SPOTMARKETORDERRESULTS.fields_by_name['fee']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _SPOTMARKETORDERRESULTS._options = None
  _SPOTMARKETORDERRESULTS._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGCREATEDERIVATIVELIMITORDER.fields_by_name['order']._options = None
  _MSGCREATEDERIVATIVELIMITORDER.fields_by_name['order']._serialized_options = b'\310\336\037\000'
  _MSGCREATEDERIVATIVELIMITORDER._options = None
  _MSGCREATEDERIVATIVELIMITORDER._serialized_options = b'\210\240\037\000'
  _MSGCREATEDERIVATIVELIMITORDERRESPONSE._options = None
  _MSGCREATEDERIVATIVELIMITORDERRESPONSE._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGCREATEBINARYOPTIONSLIMITORDER.fields_by_name['order']._options = None
  _MSGCREATEBINARYOPTIONSLIMITORDER.fields_by_name['order']._serialized_options = b'\310\336\037\000'
  _MSGCREATEBINARYOPTIONSLIMITORDER._options = None
  _MSGCREATEBINARYOPTIONSLIMITORDER._serialized_options = b'\210\240\037\000'
  _MSGCREATEBINARYOPTIONSLIMITORDERRESPONSE._options = None
  _MSGCREATEBINARYOPTIONSLIMITORDERRESPONSE._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGBATCHCREATEDERIVATIVELIMITORDERS.fields_by_name['orders']._options = None
  _MSGBATCHCREATEDERIVATIVELIMITORDERS.fields_by_name['orders']._serialized_options = b'\310\336\037\000'
  _MSGBATCHCREATEDERIVATIVELIMITORDERS._options = None
  _MSGBATCHCREATEDERIVATIVELIMITORDERS._serialized_options = b'\210\240\037\000'
  _MSGBATCHCREATEDERIVATIVELIMITORDERSRESPONSE._options = None
  _MSGBATCHCREATEDERIVATIVELIMITORDERSRESPONSE._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGCANCELSPOTORDER._options = None
  _MSGCANCELSPOTORDER._serialized_options = b'\210\240\037\000'
  _MSGBATCHCANCELSPOTORDERS.fields_by_name['data']._options = None
  _MSGBATCHCANCELSPOTORDERS.fields_by_name['data']._serialized_options = b'\310\336\037\000'
  _MSGBATCHCANCELSPOTORDERS._options = None
  _MSGBATCHCANCELSPOTORDERS._serialized_options = b'\210\240\037\000'
  _MSGBATCHCANCELSPOTORDERSRESPONSE._options = None
  _MSGBATCHCANCELSPOTORDERSRESPONSE._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGBATCHCANCELBINARYOPTIONSORDERS.fields_by_name['data']._options = None
  _MSGBATCHCANCELBINARYOPTIONSORDERS.fields_by_name['data']._serialized_options = b'\310\336\037\000'
  _MSGBATCHCANCELBINARYOPTIONSORDERS._options = None
  _MSGBATCHCANCELBINARYOPTIONSORDERS._serialized_options = b'\210\240\037\000'
  _MSGBATCHCANCELBINARYOPTIONSORDERSRESPONSE._options = None
  _MSGBATCHCANCELBINARYOPTIONSORDERSRESPONSE._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGBATCHUPDATEORDERS.fields_by_name['spot_orders_to_cancel']._options = None
  _MSGBATCHUPDATEORDERS.fields_by_name['spot_orders_to_cancel']._serialized_options = b'\310\336\037\001'
  _MSGBATCHUPDATEORDERS.fields_by_name['derivative_orders_to_cancel']._options = None
  _MSGBATCHUPDATEORDERS.fields_by_name['derivative_orders_to_cancel']._serialized_options = b'\310\336\037\001'
  _MSGBATCHUPDATEORDERS.fields_by_name['spot_orders_to_create']._options = None
  _MSGBATCHUPDATEORDERS.fields_by_name['spot_orders_to_create']._serialized_options = b'\310\336\037\001'
  _MSGBATCHUPDATEORDERS.fields_by_name['derivative_orders_to_create']._options = None
  _MSGBATCHUPDATEORDERS.fields_by_name['derivative_orders_to_create']._serialized_options = b'\310\336\037\001'
  _MSGBATCHUPDATEORDERS.fields_by_name['binary_options_orders_to_cancel']._options = None
  _MSGBATCHUPDATEORDERS.fields_by_name['binary_options_orders_to_cancel']._serialized_options = b'\310\336\037\001'
  _MSGBATCHUPDATEORDERS.fields_by_name['binary_options_orders_to_create']._options = None
  _MSGBATCHUPDATEORDERS.fields_by_name['binary_options_orders_to_create']._serialized_options = b'\310\336\037\001'
  _MSGBATCHUPDATEORDERS._options = None
  _MSGBATCHUPDATEORDERS._serialized_options = b'\210\240\037\000'
  _MSGBATCHUPDATEORDERSRESPONSE._options = None
  _MSGBATCHUPDATEORDERSRESPONSE._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGCREATEDERIVATIVEMARKETORDER.fields_by_name['order']._options = None
  _MSGCREATEDERIVATIVEMARKETORDER.fields_by_name['order']._serialized_options = b'\310\336\037\000'
  _MSGCREATEDERIVATIVEMARKETORDER._options = None
  _MSGCREATEDERIVATIVEMARKETORDER._serialized_options = b'\210\240\037\000'
  _MSGCREATEDERIVATIVEMARKETORDERRESPONSE.fields_by_name['results']._options = None
  _MSGCREATEDERIVATIVEMARKETORDERRESPONSE.fields_by_name['results']._serialized_options = b'\310\336\037\001'
  _MSGCREATEDERIVATIVEMARKETORDERRESPONSE._options = None
  _MSGCREATEDERIVATIVEMARKETORDERRESPONSE._serialized_options = b'\350\240\037\000\210\240\037\000'
  _DERIVATIVEMARKETORDERRESULTS.fields_by_name['quantity']._options = None
  _DERIVATIVEMARKETORDERRESULTS.fields_by_name['quantity']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _DERIVATIVEMARKETORDERRESULTS.fields_by_name['price']._options = None
  _DERIVATIVEMARKETORDERRESULTS.fields_by_name['price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _DERIVATIVEMARKETORDERRESULTS.fields_by_name['fee']._options = None
  _DERIVATIVEMARKETORDERRESULTS.fields_by_name['fee']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _DERIVATIVEMARKETORDERRESULTS.fields_by_name['position_delta']._options = None
  _DERIVATIVEMARKETORDERRESULTS.fields_by_name['position_delta']._serialized_options = b'\310\336\037\000'
  _DERIVATIVEMARKETORDERRESULTS.fields_by_name['payout']._options = None
  _DERIVATIVEMARKETORDERRESULTS.fields_by_name['payout']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _DERIVATIVEMARKETORDERRESULTS._options = None
  _DERIVATIVEMARKETORDERRESULTS._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGCREATEBINARYOPTIONSMARKETORDER.fields_by_name['order']._options = None
  _MSGCREATEBINARYOPTIONSMARKETORDER.fields_by_name['order']._serialized_options = b'\310\336\037\000'
  _MSGCREATEBINARYOPTIONSMARKETORDER._options = None
  _MSGCREATEBINARYOPTIONSMARKETORDER._serialized_options = b'\210\240\037\000'
  _MSGCREATEBINARYOPTIONSMARKETORDERRESPONSE.fields_by_name['results']._options = None
  _MSGCREATEBINARYOPTIONSMARKETORDERRESPONSE.fields_by_name['results']._serialized_options = b'\310\336\037\001'
  _MSGCREATEBINARYOPTIONSMARKETORDERRESPONSE._options = None
  _MSGCREATEBINARYOPTIONSMARKETORDERRESPONSE._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGCANCELDERIVATIVEORDER._options = None
  _MSGCANCELDERIVATIVEORDER._serialized_options = b'\210\240\037\000'
  _MSGCANCELBINARYOPTIONSORDER._options = None
  _MSGCANCELBINARYOPTIONSORDER._serialized_options = b'\210\240\037\000'
  _MSGBATCHCANCELDERIVATIVEORDERS.fields_by_name['data']._options = None
  _MSGBATCHCANCELDERIVATIVEORDERS.fields_by_name['data']._serialized_options = b'\310\336\037\000'
  _MSGBATCHCANCELDERIVATIVEORDERS._options = None
  _MSGBATCHCANCELDERIVATIVEORDERS._serialized_options = b'\210\240\037\000'
  _MSGBATCHCANCELDERIVATIVEORDERSRESPONSE._options = None
  _MSGBATCHCANCELDERIVATIVEORDERSRESPONSE._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGSUBACCOUNTTRANSFER.fields_by_name['amount']._options = None
  _MSGSUBACCOUNTTRANSFER.fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _MSGEXTERNALTRANSFER.fields_by_name['amount']._options = None
  _MSGEXTERNALTRANSFER.fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _MSGLIQUIDATEPOSITION.fields_by_name['order']._options = None
  _MSGLIQUIDATEPOSITION.fields_by_name['order']._serialized_options = b'\310\336\037\001'
  _MSGINCREASEPOSITIONMARGIN.fields_by_name['amount']._options = None
  _MSGINCREASEPOSITIONMARGIN.fields_by_name['amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _MSGPRIVILEGEDEXECUTECONTRACT._options = None
  _MSGPRIVILEGEDEXECUTECONTRACT._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGPRIVILEGEDEXECUTECONTRACTRESPONSE.fields_by_name['funds_diff']._options = None
  _MSGPRIVILEGEDEXECUTECONTRACTRESPONSE.fields_by_name['funds_diff']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _MSGPRIVILEGEDEXECUTECONTRACTRESPONSE._options = None
  _MSGPRIVILEGEDEXECUTECONTRACTRESPONSE._serialized_options = b'\350\240\037\000\210\240\037\000'
  _SPOTMARKETPARAMUPDATEPROPOSAL.fields_by_name['maker_fee_rate']._options = None
  _SPOTMARKETPARAMUPDATEPROPOSAL.fields_by_name['maker_fee_rate']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001'
  _SPOTMARKETPARAMUPDATEPROPOSAL.fields_by_name['taker_fee_rate']._options = None
  _SPOTMARKETPARAMUPDATEPROPOSAL.fields_by_name['taker_fee_rate']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001'
  _SPOTMARKETPARAMUPDATEPROPOSAL.fields_by_name['relayer_fee_share_rate']._options = None
  _SPOTMARKETPARAMUPDATEPROPOSAL.fields_by_name['relayer_fee_share_rate']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001'
  _SPOTMARKETPARAMUPDATEPROPOSAL.fields_by_name['min_price_tick_size']._options = None
  _SPOTMARKETPARAMUPDATEPROPOSAL.fields_by_name['min_price_tick_size']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001'
  _SPOTMARKETPARAMUPDATEPROPOSAL.fields_by_name['min_quantity_tick_size']._options = None
  _SPOTMARKETPARAMUPDATEPROPOSAL.fields_by_name['min_quantity_tick_size']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001'
  _SPOTMARKETPARAMUPDATEPROPOSAL._options = None
  _SPOTMARKETPARAMUPDATEPROPOSAL._serialized_options = b'\350\240\037\000\210\240\037\000'
  _EXCHANGEENABLEPROPOSAL._options = None
  _EXCHANGEENABLEPROPOSAL._serialized_options = b'\350\240\037\000\210\240\037\000'
  _BATCHEXCHANGEMODIFICATIONPROPOSAL._options = None
  _BATCHEXCHANGEMODIFICATIONPROPOSAL._serialized_options = b'\350\240\037\000\210\240\037\000'
  _SPOTMARKETLAUNCHPROPOSAL.fields_by_name['min_price_tick_size']._options = None
  _SPOTMARKETLAUNCHPROPOSAL.fields_by_name['min_price_tick_size']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _SPOTMARKETLAUNCHPROPOSAL.fields_by_name['min_quantity_tick_size']._options = None
  _SPOTMARKETLAUNCHPROPOSAL.fields_by_name['min_quantity_tick_size']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _SPOTMARKETLAUNCHPROPOSAL.fields_by_name['maker_fee_rate']._options = None
  _SPOTMARKETLAUNCHPROPOSAL.fields_by_name['maker_fee_rate']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001'
  _SPOTMARKETLAUNCHPROPOSAL.fields_by_name['taker_fee_rate']._options = None
  _SPOTMARKETLAUNCHPROPOSAL.fields_by_name['taker_fee_rate']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001'
  _SPOTMARKETLAUNCHPROPOSAL._options = None
  _SPOTMARKETLAUNCHPROPOSAL._serialized_options = b'\350\240\037\000\210\240\037\000'
  _PERPETUALMARKETLAUNCHPROPOSAL.fields_by_name['initial_margin_ratio']._options = None
  _PERPETUALMARKETLAUNCHPROPOSAL.fields_by_name['initial_margin_ratio']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PERPETUALMARKETLAUNCHPROPOSAL.fields_by_name['maintenance_margin_ratio']._options = None
  _PERPETUALMARKETLAUNCHPROPOSAL.fields_by_name['maintenance_margin_ratio']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PERPETUALMARKETLAUNCHPROPOSAL.fields_by_name['maker_fee_rate']._options = None
  _PERPETUALMARKETLAUNCHPROPOSAL.fields_by_name['maker_fee_rate']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PERPETUALMARKETLAUNCHPROPOSAL.fields_by_name['taker_fee_rate']._options = None
  _PERPETUALMARKETLAUNCHPROPOSAL.fields_by_name['taker_fee_rate']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PERPETUALMARKETLAUNCHPROPOSAL.fields_by_name['min_price_tick_size']._options = None
  _PERPETUALMARKETLAUNCHPROPOSAL.fields_by_name['min_price_tick_size']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PERPETUALMARKETLAUNCHPROPOSAL.fields_by_name['min_quantity_tick_size']._options = None
  _PERPETUALMARKETLAUNCHPROPOSAL.fields_by_name['min_quantity_tick_size']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PERPETUALMARKETLAUNCHPROPOSAL._options = None
  _PERPETUALMARKETLAUNCHPROPOSAL._serialized_options = b'\350\240\037\000\210\240\037\000'
  _BINARYOPTIONSMARKETLAUNCHPROPOSAL.fields_by_name['maker_fee_rate']._options = None
  _BINARYOPTIONSMARKETLAUNCHPROPOSAL.fields_by_name['maker_fee_rate']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _BINARYOPTIONSMARKETLAUNCHPROPOSAL.fields_by_name['taker_fee_rate']._options = None
  _BINARYOPTIONSMARKETLAUNCHPROPOSAL.fields_by_name['taker_fee_rate']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _BINARYOPTIONSMARKETLAUNCHPROPOSAL.fields_by_name['min_price_tick_size']._options = None
  _BINARYOPTIONSMARKETLAUNCHPROPOSAL.fields_by_name['min_price_tick_size']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _BINARYOPTIONSMARKETLAUNCHPROPOSAL.fields_by_name['min_quantity_tick_size']._options = None
  _BINARYOPTIONSMARKETLAUNCHPROPOSAL.fields_by_name['min_quantity_tick_size']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _BINARYOPTIONSMARKETLAUNCHPROPOSAL._options = None
  _BINARYOPTIONSMARKETLAUNCHPROPOSAL._serialized_options = b'\350\240\037\000\210\240\037\000'
  _EXPIRYFUTURESMARKETLAUNCHPROPOSAL.fields_by_name['initial_margin_ratio']._options = None
  _EXPIRYFUTURESMARKETLAUNCHPROPOSAL.fields_by_name['initial_margin_ratio']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _EXPIRYFUTURESMARKETLAUNCHPROPOSAL.fields_by_name['maintenance_margin_ratio']._options = None
  _EXPIRYFUTURESMARKETLAUNCHPROPOSAL.fields_by_name['maintenance_margin_ratio']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _EXPIRYFUTURESMARKETLAUNCHPROPOSAL.fields_by_name['maker_fee_rate']._options = None
  _EXPIRYFUTURESMARKETLAUNCHPROPOSAL.fields_by_name['maker_fee_rate']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _EXPIRYFUTURESMARKETLAUNCHPROPOSAL.fields_by_name['taker_fee_rate']._options = None
  _EXPIRYFUTURESMARKETLAUNCHPROPOSAL.fields_by_name['taker_fee_rate']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _EXPIRYFUTURESMARKETLAUNCHPROPOSAL.fields_by_name['min_price_tick_size']._options = None
  _EXPIRYFUTURESMARKETLAUNCHPROPOSAL.fields_by_name['min_price_tick_size']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _EXPIRYFUTURESMARKETLAUNCHPROPOSAL.fields_by_name['min_quantity_tick_size']._options = None
  _EXPIRYFUTURESMARKETLAUNCHPROPOSAL.fields_by_name['min_quantity_tick_size']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _EXPIRYFUTURESMARKETLAUNCHPROPOSAL._options = None
  _EXPIRYFUTURESMARKETLAUNCHPROPOSAL._serialized_options = b'\350\240\037\000\210\240\037\000'
  _DERIVATIVEMARKETPARAMUPDATEPROPOSAL.fields_by_name['initial_margin_ratio']._options = None
  _DERIVATIVEMARKETPARAMUPDATEPROPOSAL.fields_by_name['initial_margin_ratio']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001'
  _DERIVATIVEMARKETPARAMUPDATEPROPOSAL.fields_by_name['maintenance_margin_ratio']._options = None
  _DERIVATIVEMARKETPARAMUPDATEPROPOSAL.fields_by_name['maintenance_margin_ratio']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001'
  _DERIVATIVEMARKETPARAMUPDATEPROPOSAL.fields_by_name['maker_fee_rate']._options = None
  _DERIVATIVEMARKETPARAMUPDATEPROPOSAL.fields_by_name['maker_fee_rate']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001'
  _DERIVATIVEMARKETPARAMUPDATEPROPOSAL.fields_by_name['taker_fee_rate']._options = None
  _DERIVATIVEMARKETPARAMUPDATEPROPOSAL.fields_by_name['taker_fee_rate']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001'
  _DERIVATIVEMARKETPARAMUPDATEPROPOSAL.fields_by_name['relayer_fee_share_rate']._options = None
  _DERIVATIVEMARKETPARAMUPDATEPROPOSAL.fields_by_name['relayer_fee_share_rate']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001'
  _DERIVATIVEMARKETPARAMUPDATEPROPOSAL.fields_by_name['min_price_tick_size']._options = None
  _DERIVATIVEMARKETPARAMUPDATEPROPOSAL.fields_by_name['min_price_tick_size']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001'
  _DERIVATIVEMARKETPARAMUPDATEPROPOSAL.fields_by_name['min_quantity_tick_size']._options = None
  _DERIVATIVEMARKETPARAMUPDATEPROPOSAL.fields_by_name['min_quantity_tick_size']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001'
  _DERIVATIVEMARKETPARAMUPDATEPROPOSAL.fields_by_name['HourlyInterestRate']._options = None
  _DERIVATIVEMARKETPARAMUPDATEPROPOSAL.fields_by_name['HourlyInterestRate']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001'
  _DERIVATIVEMARKETPARAMUPDATEPROPOSAL.fields_by_name['HourlyFundingRateCap']._options = None
  _DERIVATIVEMARKETPARAMUPDATEPROPOSAL.fields_by_name['HourlyFundingRateCap']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001'
  _DERIVATIVEMARKETPARAMUPDATEPROPOSAL._options = None
  _DERIVATIVEMARKETPARAMUPDATEPROPOSAL._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MARKETFORCEDSETTLEMENTPROPOSAL.fields_by_name['settlement_price']._options = None
  _MARKETFORCEDSETTLEMENTPROPOSAL.fields_by_name['settlement_price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001'
  _MARKETFORCEDSETTLEMENTPROPOSAL._options = None
  _MARKETFORCEDSETTLEMENTPROPOSAL._serialized_options = b'\350\240\037\000\210\240\037\000'
  _UPDATEDENOMDECIMALSPROPOSAL._options = None
  _UPDATEDENOMDECIMALSPROPOSAL._serialized_options = b'\350\240\037\000\210\240\037\000'
  _BINARYOPTIONSMARKETPARAMUPDATEPROPOSAL.fields_by_name['maker_fee_rate']._options = None
  _BINARYOPTIONSMARKETPARAMUPDATEPROPOSAL.fields_by_name['maker_fee_rate']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001'
  _BINARYOPTIONSMARKETPARAMUPDATEPROPOSAL.fields_by_name['taker_fee_rate']._options = None
  _BINARYOPTIONSMARKETPARAMUPDATEPROPOSAL.fields_by_name['taker_fee_rate']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001'
  _BINARYOPTIONSMARKETPARAMUPDATEPROPOSAL.fields_by_name['relayer_fee_share_rate']._options = None
  _BINARYOPTIONSMARKETPARAMUPDATEPROPOSAL.fields_by_name['relayer_fee_share_rate']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001'
  _BINARYOPTIONSMARKETPARAMUPDATEPROPOSAL.fields_by_name['min_price_tick_size']._options = None
  _BINARYOPTIONSMARKETPARAMUPDATEPROPOSAL.fields_by_name['min_price_tick_size']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001'
  _BINARYOPTIONSMARKETPARAMUPDATEPROPOSAL.fields_by_name['min_quantity_tick_size']._options = None
  _BINARYOPTIONSMARKETPARAMUPDATEPROPOSAL.fields_by_name['min_quantity_tick_size']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001'
  _BINARYOPTIONSMARKETPARAMUPDATEPROPOSAL.fields_by_name['settlement_price']._options = None
  _BINARYOPTIONSMARKETPARAMUPDATEPROPOSAL.fields_by_name['settlement_price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001'
  _BINARYOPTIONSMARKETPARAMUPDATEPROPOSAL._options = None
  _BINARYOPTIONSMARKETPARAMUPDATEPROPOSAL._serialized_options = b'\350\240\037\000\210\240\037\000'
  _TRADINGREWARDCAMPAIGNLAUNCHPROPOSAL._options = None
  _TRADINGREWARDCAMPAIGNLAUNCHPROPOSAL._serialized_options = b'\350\240\037\000\210\240\037\000'
  _TRADINGREWARDCAMPAIGNUPDATEPROPOSAL._options = None
  _TRADINGREWARDCAMPAIGNUPDATEPROPOSAL._serialized_options = b'\350\240\037\000\210\240\037\000'
  _REWARDPOINTUPDATE.fields_by_name['new_points']._options = None
  _REWARDPOINTUPDATE.fields_by_name['new_points']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _TRADINGREWARDPENDINGPOINTSUPDATEPROPOSAL._options = None
  _TRADINGREWARDPENDINGPOINTSUPDATEPROPOSAL._serialized_options = b'\350\240\037\000\210\240\037\000'
  _FEEDISCOUNTPROPOSAL._options = None
  _FEEDISCOUNTPROPOSAL._serialized_options = b'\350\240\037\000\210\240\037\000'
  _BATCHCOMMUNITYPOOLSPENDPROPOSAL._options = None
  _BATCHCOMMUNITYPOOLSPENDPROPOSAL._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGSIGNDATA.fields_by_name['Signer']._options = None
  _MSGSIGNDATA.fields_by_name['Signer']._serialized_options = b'\352\336\037\006signer\372\336\037-github.com/cosmos/cosmos-sdk/types.AccAddress'
  _MSGSIGNDATA.fields_by_name['Data']._options = None
  _MSGSIGNDATA.fields_by_name['Data']._serialized_options = b'\352\336\037\004data'
  _MSGSIGNDOC.fields_by_name['sign_type']._options = None
  _MSGSIGNDOC.fields_by_name['sign_type']._serialized_options = b'\352\336\037\004type'
  _MSGSIGNDOC.fields_by_name['value']._options = None
  _MSGSIGNDOC.fields_by_name['value']._serialized_options = b'\310\336\037\000'
  _MSGADMINUPDATEBINARYOPTIONSMARKET.fields_by_name['settlement_price']._options = None
  _MSGADMINUPDATEBINARYOPTIONSMARKET.fields_by_name['settlement_price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001'
  _ATOMICMARKETORDERFEEMULTIPLIERSCHEDULEPROPOSAL._options = None
  _ATOMICMARKETORDERFEEMULTIPLIERSCHEDULEPROPOSAL._serialized_options = b'\350\240\037\000\210\240\037\000'
  _EXCHANGETYPE._serialized_start=17120
  _EXCHANGETYPE._serialized_end=17240
  _MSGDEPOSIT._serialized_start=278
  _MSGDEPOSIT._serialized_end=388
  _MSGDEPOSITRESPONSE._serialized_start=390
  _MSGDEPOSITRESPONSE._serialized_end=410
  _MSGWITHDRAW._serialized_start=412
  _MSGWITHDRAW._serialized_end=523
  _MSGWITHDRAWRESPONSE._serialized_start=525
  _MSGWITHDRAWRESPONSE._serialized_end=546
  _MSGCREATESPOTLIMITORDER._serialized_start=548
  _MSGCREATESPOTLIMITORDER._serialized_end=659
  _MSGCREATESPOTLIMITORDERRESPONSE._serialized_start=661
  _MSGCREATESPOTLIMITORDERRESPONSE._serialized_end=724
  _MSGBATCHCREATESPOTLIMITORDERS._serialized_start=726
  _MSGBATCHCREATESPOTLIMITORDERS._serialized_end=844
  _MSGBATCHCREATESPOTLIMITORDERSRESPONSE._serialized_start=846
  _MSGBATCHCREATESPOTLIMITORDERSRESPONSE._serialized_end=917
  _MSGINSTANTSPOTMARKETLAUNCH._serialized_start=920
  _MSGINSTANTSPOTMARKETLAUNCH._serialized_end=1188
  _MSGINSTANTSPOTMARKETLAUNCHRESPONSE._serialized_start=1190
  _MSGINSTANTSPOTMARKETLAUNCHRESPONSE._serialized_end=1226
  _MSGINSTANTPERPETUALMARKETLAUNCH._serialized_start=1229
  _MSGINSTANTPERPETUALMARKETLAUNCH._serialized_end=1917
  _MSGINSTANTPERPETUALMARKETLAUNCHRESPONSE._serialized_start=1919
  _MSGINSTANTPERPETUALMARKETLAUNCHRESPONSE._serialized_end=1960
  _MSGINSTANTBINARYOPTIONSMARKETLAUNCH._serialized_start=1963
  _MSGINSTANTBINARYOPTIONSMARKETLAUNCH._serialized_end=2575
  _MSGINSTANTBINARYOPTIONSMARKETLAUNCHRESPONSE._serialized_start=2577
  _MSGINSTANTBINARYOPTIONSMARKETLAUNCHRESPONSE._serialized_end=2622
  _MSGINSTANTEXPIRYFUTURESMARKETLAUNCH._serialized_start=2625
  _MSGINSTANTEXPIRYFUTURESMARKETLAUNCH._serialized_end=3333
  _MSGINSTANTEXPIRYFUTURESMARKETLAUNCHRESPONSE._serialized_start=3335
  _MSGINSTANTEXPIRYFUTURESMARKETLAUNCHRESPONSE._serialized_end=3380
  _MSGCREATESPOTMARKETORDER._serialized_start=3382
  _MSGCREATESPOTMARKETORDER._serialized_end=3494
  _MSGCREATESPOTMARKETORDERRESPONSE._serialized_start=3497
  _MSGCREATESPOTMARKETORDERRESPONSE._serialized_end=3636
  _SPOTMARKETORDERRESULTS._serialized_start=3639
  _SPOTMARKETORDERRESULTS._serialized_end=3863
  _MSGCREATEDERIVATIVELIMITORDER._serialized_start=3865
  _MSGCREATEDERIVATIVELIMITORDER._serialized_end=3984
  _MSGCREATEDERIVATIVELIMITORDERRESPONSE._serialized_start=3986
  _MSGCREATEDERIVATIVELIMITORDERRESPONSE._serialized_end=4055
  _MSGCREATEBINARYOPTIONSLIMITORDER._serialized_start=4057
  _MSGCREATEBINARYOPTIONSLIMITORDER._serialized_end=4179
  _MSGCREATEBINARYOPTIONSLIMITORDERRESPONSE._serialized_start=4181
  _MSGCREATEBINARYOPTIONSLIMITORDERRESPONSE._serialized_end=4253
  _MSGBATCHCREATEDERIVATIVELIMITORDERS._serialized_start=4255
  _MSGBATCHCREATEDERIVATIVELIMITORDERS._serialized_end=4381
  _MSGBATCHCREATEDERIVATIVELIMITORDERSRESPONSE._serialized_start=4383
  _MSGBATCHCREATEDERIVATIVELIMITORDERSRESPONSE._serialized_end=4460
  _MSGCANCELSPOTORDER._serialized_start=4462
  _MSGCANCELSPOTORDER._serialized_end=4566
  _MSGCANCELSPOTORDERRESPONSE._serialized_start=4568
  _MSGCANCELSPOTORDERRESPONSE._serialized_end=4596
  _MSGBATCHCANCELSPOTORDERS._serialized_start=4598
  _MSGBATCHCANCELSPOTORDERS._serialized_end=4705
  _MSGBATCHCANCELSPOTORDERSRESPONSE._serialized_start=4707
  _MSGBATCHCANCELSPOTORDERSRESPONSE._serialized_end=4768
  _MSGBATCHCANCELBINARYOPTIONSORDERS._serialized_start=4770
  _MSGBATCHCANCELBINARYOPTIONSORDERS._serialized_end=4886
  _MSGBATCHCANCELBINARYOPTIONSORDERSRESPONSE._serialized_start=4888
  _MSGBATCHCANCELBINARYOPTIONSORDERSRESPONSE._serialized_end=4958
  _MSGBATCHUPDATEORDERS._serialized_start=4961
  _MSGBATCHUPDATEORDERS._serialized_end=5661
  _MSGBATCHUPDATEORDERSRESPONSE._serialized_start=5664
  _MSGBATCHUPDATEORDERSRESPONSE._serialized_end=5904
  _MSGCREATEDERIVATIVEMARKETORDER._serialized_start=5906
  _MSGCREATEDERIVATIVEMARKETORDER._serialized_end=6026
  _MSGCREATEDERIVATIVEMARKETORDERRESPONSE._serialized_start=6029
  _MSGCREATEDERIVATIVEMARKETORDERRESPONSE._serialized_end=6180
  _DERIVATIVEMARKETORDERRESULTS._serialized_start=6183
  _DERIVATIVEMARKETORDERRESULTS._serialized_end=6550
  _MSGCREATEBINARYOPTIONSMARKETORDER._serialized_start=6552
  _MSGCREATEBINARYOPTIONSMARKETORDER._serialized_end=6675
  _MSGCREATEBINARYOPTIONSMARKETORDERRESPONSE._serialized_start=6678
  _MSGCREATEBINARYOPTIONSMARKETORDERRESPONSE._serialized_end=6832
  _MSGCANCELDERIVATIVEORDER._serialized_start=6835
  _MSGCANCELDERIVATIVEORDER._serialized_end=6965
  _MSGCANCELDERIVATIVEORDERRESPONSE._serialized_start=6967
  _MSGCANCELDERIVATIVEORDERRESPONSE._serialized_end=7001
  _MSGCANCELBINARYOPTIONSORDER._serialized_start=7004
  _MSGCANCELBINARYOPTIONSORDER._serialized_end=7137
  _MSGCANCELBINARYOPTIONSORDERRESPONSE._serialized_start=7139
  _MSGCANCELBINARYOPTIONSORDERRESPONSE._serialized_end=7176
  _ORDERDATA._serialized_start=7178
  _ORDERDATA._serialized_end=7271
  _MSGBATCHCANCELDERIVATIVEORDERS._serialized_start=7273
  _MSGBATCHCANCELDERIVATIVEORDERS._serialized_end=7386
  _MSGBATCHCANCELDERIVATIVEORDERSRESPONSE._serialized_start=7388
  _MSGBATCHCANCELDERIVATIVEORDERSRESPONSE._serialized_end=7455
  _MSGSUBACCOUNTTRANSFER._serialized_start=7458
  _MSGSUBACCOUNTTRANSFER._serialized_end=7611
  _MSGSUBACCOUNTTRANSFERRESPONSE._serialized_start=7613
  _MSGSUBACCOUNTTRANSFERRESPONSE._serialized_end=7644
  _MSGEXTERNALTRANSFER._serialized_start=7647
  _MSGEXTERNALTRANSFER._serialized_end=7798
  _MSGEXTERNALTRANSFERRESPONSE._serialized_start=7800
  _MSGEXTERNALTRANSFERRESPONSE._serialized_end=7829
  _MSGLIQUIDATEPOSITION._serialized_start=7832
  _MSGLIQUIDATEPOSITION._serialized_end=7978
  _MSGLIQUIDATEPOSITIONRESPONSE._serialized_start=7980
  _MSGLIQUIDATEPOSITIONRESPONSE._serialized_end=8010
  _MSGINCREASEPOSITIONMARGIN._serialized_start=8013
  _MSGINCREASEPOSITIONMARGIN._serialized_end=8204
  _MSGINCREASEPOSITIONMARGINRESPONSE._serialized_start=8206
  _MSGINCREASEPOSITIONMARGINRESPONSE._serialized_end=8241
  _MSGPRIVILEGEDEXECUTECONTRACT._serialized_start=8243
  _MSGPRIVILEGEDEXECUTECONTRACT._serialized_end=8354
  _MSGPRIVILEGEDEXECUTECONTRACTRESPONSE._serialized_start=8357
  _MSGPRIVILEGEDEXECUTECONTRACTRESPONSE._serialized_end=8502
  _SPOTMARKETPARAMUPDATEPROPOSAL._serialized_start=8505
  _SPOTMARKETPARAMUPDATEPROPOSAL._serialized_end=9040
  _EXCHANGEENABLEPROPOSAL._serialized_start=9043
  _EXCHANGEENABLEPROPOSAL._serialized_end=9177
  _BATCHEXCHANGEMODIFICATIONPROPOSAL._serialized_start=9180
  _BATCHEXCHANGEMODIFICATIONPROPOSAL._serialized_end=10221
  _SPOTMARKETLAUNCHPROPOSAL._serialized_start=10224
  _SPOTMARKETLAUNCHPROPOSAL._serialized_end=10654
  _PERPETUALMARKETLAUNCHPROPOSAL._serialized_start=10657
  _PERPETUALMARKETLAUNCHPROPOSAL._serialized_end=11363
  _BINARYOPTIONSMARKETLAUNCHPROPOSAL._serialized_start=11366
  _BINARYOPTIONSMARKETLAUNCHPROPOSAL._serialized_end=11996
  _EXPIRYFUTURESMARKETLAUNCHPROPOSAL._serialized_start=11999
  _EXPIRYFUTURESMARKETLAUNCHPROPOSAL._serialized_end=12725
  _DERIVATIVEMARKETPARAMUPDATEPROPOSAL._serialized_start=12728
  _DERIVATIVEMARKETPARAMUPDATEPROPOSAL._serialized_end=13648
  _MARKETFORCEDSETTLEMENTPROPOSAL._serialized_start=13651
  _MARKETFORCEDSETTLEMENTPROPOSAL._serialized_end=13822
  _UPDATEDENOMDECIMALSPROPOSAL._serialized_start=13825
  _UPDATEDENOMDECIMALSPROPOSAL._serialized_end=13967
  _BINARYOPTIONSMARKETPARAMUPDATEPROPOSAL._serialized_start=13970
  _BINARYOPTIONSMARKETPARAMUPDATEPROPOSAL._serialized_end=14736
  _PROVIDERORACLEPARAMS._serialized_start=14739
  _PROVIDERORACLEPARAMS._serialized_end=14883
  _ORACLEPARAMS._serialized_start=14886
  _ORACLEPARAMS._serialized_end=15031
  _TRADINGREWARDCAMPAIGNLAUNCHPROPOSAL._serialized_start=15034
  _TRADINGREWARDCAMPAIGNLAUNCHPROPOSAL._serialized_end=15274
  _TRADINGREWARDCAMPAIGNUPDATEPROPOSAL._serialized_start=15277
  _TRADINGREWARDCAMPAIGNUPDATEPROPOSAL._serialized_end=15614
  _REWARDPOINTUPDATE._serialized_start=15616
  _REWARDPOINTUPDATE._serialized_end=15728
  _TRADINGREWARDPENDINGPOINTSUPDATEPROPOSAL._serialized_start=15731
  _TRADINGREWARDPENDINGPOINTSUPDATEPROPOSAL._serialized_end=15928
  _FEEDISCOUNTPROPOSAL._serialized_start=15931
  _FEEDISCOUNTPROPOSAL._serialized_end=16065
  _BATCHCOMMUNITYPOOLSPENDPROPOSAL._serialized_start=16068
  _BATCHCOMMUNITYPOOLSPENDPROPOSAL._serialized_end=16223
  _MSGREWARDSOPTOUT._serialized_start=16225
  _MSGREWARDSOPTOUT._serialized_end=16259
  _MSGREWARDSOPTOUTRESPONSE._serialized_start=16261
  _MSGREWARDSOPTOUTRESPONSE._serialized_end=16287
  _MSGRECLAIMLOCKEDFUNDS._serialized_start=16289
  _MSGRECLAIMLOCKEDFUNDS._serialized_end=16376
  _MSGRECLAIMLOCKEDFUNDSRESPONSE._serialized_start=16378
  _MSGRECLAIMLOCKEDFUNDSRESPONSE._serialized_end=16409
  _MSGSIGNDATA._serialized_start=16411
  _MSGSIGNDATA._serialized_end=16525
  _MSGSIGNDOC._serialized_start=16527
  _MSGSIGNDOC._serialized_end=16630
  _MSGADMINUPDATEBINARYOPTIONSMARKET._serialized_start=16633
  _MSGADMINUPDATEBINARYOPTIONSMARKET._serialized_end=16895
  _MSGADMINUPDATEBINARYOPTIONSMARKETRESPONSE._serialized_start=16897
  _MSGADMINUPDATEBINARYOPTIONSMARKETRESPONSE._serialized_end=16940
  _ATOMICMARKETORDERFEEMULTIPLIERSCHEDULEPROPOSAL._serialized_start=16943
  _ATOMICMARKETORDERFEEMULTIPLIERSCHEDULEPROPOSAL._serialized_end=17118
  _MSG._serialized_start=17243
  _MSG._serialized_end=21497
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/peggy/v1/ethereum_signer.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(injective/peggy/v1/ethereum_signer.proto\x12\x12injective.peggy.v1\x1a\x14gogoproto/gogo.proto*\x91\x01\n\x08SignType\x12\x15\n\x11SIGN_TYPE_UNKNOWN\x10\x00\x12\x32\n.SIGN_TYPE_ORCHESTRATOR_SIGNED_MULTI_SIG_UPDATE\x10\x01\x12\x30\n,SIGN_TYPE_ORCHESTRATOR_SIGNED_WITHDRAW_BATCH\x10\x02\x1a\x08\x88\xa3\x1e\x00\xa8\xa4\x1e\x00\x42MZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.peggy.v1.ethereum_signer_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/types'
  _SIGNTYPE._options = None
  _SIGNTYPE._serialized_options = b'\210\243\036\000\250\244\036\000'
  _SIGNTYPE._serialized_start=87
  _SIGNTYPE._serialized_end=232
# @@protoc_insertion_point(module_scope)
